(->hedge-timer event)converts AWS specific timer payload to Hedge handler unified format
converts AWS specific timer payload to Hedge handler unified format
(lambda-apigw-function-wrapper handler)(lambda-apigw-function-wrapper handler codec)(lambda-queue-function-wrapper handler)wrapper for AWS queue events
wrapper for AWS queue events
(lambda-timer-function-wrapper handler)wrapper for AWS timer events
wrapper for AWS timer events
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |