(azure->queue message)Converts incoming queue message to Hedge queue message handler
Converts incoming queue message to Hedge queue message handler
(azure->timer timer)Converts incoming timer trigger to Hedge timer handler
Converts incoming timer trigger to Hedge timer handler
(azure-api-function-wrapper handler & {:keys [inputs outputs]})wrapper used for http in / http out api function
wrapper used for http in / http out api function
(azure-queue-function-wrapper handler & {:keys [inputs outputs]})wrapper used for timer-triggered function
wrapper used for timer-triggered function
(azure-timer-function-wrapper handler & {:keys [inputs outputs]})wrapper used for timer-triggered function
wrapper used for timer-triggered function
(bindings->inputs context inputs)Context.bindings mapping for inputs
Context.bindings mapping for inputs
(outputs->bindings context outputs)bind outputs to bindings
bind outputs to bindings
(queue->azure context & {:keys [outputs]})Returns queue triggered handlers result to azure
Returns queue triggered handlers result to azure
(timer->azure context & {:keys [outputs]})Returns timers result to azure
Returns timers result to azure
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |